@@ -6,9 +6,9 @@
 # pylint: disable=line-too-long
 
 import json
-import re
 import azure.cli.core.azclierror as CLIErrors
 
+from datetime import datetime
 from knack.log import get_logger
 from knack.util import CLIError
 from azure.cli.core.azclierror import (InvalidArgumentValueError,
@@ -30,11 +30,22 @@ logger = get_logger(__name__)
 
 
 def validate_datetime(namespace):
-    ''' valid datetime format:YYYY-MM-DDThh:mm:ssZ '''
-    datetime_format = '^[0-9]{4}-(0[1-9]|1[0-2])-(0[1-9]|[1-2][0-9]|3[0-1])T(2[0-3]|[01][0-9]):[0-5][0-9]:[0-5][0-9][a-zA-Z]{0,5}$'
-    if namespace.datetime is not None and re.search(datetime_format, namespace.datetime) is None:
-        raise CLIError(
-            'The input datetime is invalid. Correct format should be YYYY-MM-DDThh:mm:ssZ ')
+    ''' valid datetime format: YYYY-MM-DDThh:mm:ss["Z"/±hh:mm]'''
+    supported_formats = ["%Y-%m-%dT%H:%M:%S", "%Y-%m-%dT%H:%M:%Sz", "%Y-%m-%dT%H:%M:%S%z"]
+    if namespace.datetime is not None:
+        for supported_format in supported_formats:
+            if __tryparse_datetime(namespace.datetime, supported_format):
+                return
+
+        raise InvalidArgumentValueError('The input datetime is invalid. Correct format should be YYYY-MM-DDThh:mm:ss["Z"/±hh:mm].')
+
+
+def __tryparse_datetime(datetime_string, dt_format):
+    try:
+        datetime.strptime(datetime_string, dt_format)
+        return True
+    except ValueError:
+        return False
 
 
 def validate_connection_string(cmd, namespace):
@@ -283,6 +294,8 @@ def validate_import_profile(namespace):
             raise __construct_kvset_invalid_argument_error(is_exporting=False, argument='prefix')
         if namespace.skip_features:
             raise __construct_kvset_invalid_argument_error(is_exporting=False, argument='skip-features')
+        if namespace.tags:
+            raise __construct_kvset_invalid_argument_error(is_exporting=False, argument='tags')
 
 
 def validate_export_profile(namespace):
@@ -299,6 +312,8 @@ def validate_export_profile(namespace):
             raise __construct_kvset_invalid_argument_error(is_exporting=True, argument='resolve-keyvault')
         if namespace.separator is not None:
             raise __construct_kvset_invalid_argument_error(is_exporting=True, argument='separator')
+        if namespace.dest_tags:
+            raise __construct_kvset_invalid_argument_error(is_exporting=True, argument='dest-tags')
 
 
 def validate_strict_import(namespace):
@@ -353,6 +368,10 @@ def validate_snapshot_filters(namespace):
                 if parsed_filter.get("label", None) and not isinstance(parsed_filter["label"], str):
                     raise InvalidArgumentValueError("Label filter must be a string if specified.")
 
+                if parsed_filter.get("tags", None):
+                    if not isinstance(parsed_filter["tags"], list) or not all(isinstance(tag, str) for tag in parsed_filter["tags"]):
+                        raise InvalidArgumentValueError("Tags filter must be a list of strings if specified.")
+
                 filter_parameters.append(parsed_filter)
 
             except ValueError:
@@ -378,7 +397,7 @@ def validate_snapshot_import(namespace):
 def validate_sku(namespace):
     if namespace.sku.lower() == 'free':
         if (namespace.enable_purge_protection or namespace.retention_days or namespace.replica_name or namespace.replica_location or namespace.no_replica or namespace.enable_arm_private_network_access):  # pylint: disable=too-many-boolean-expressions
-            logger.warning("Options '--enable-purge-protection', '--replica-name', '--replica-location' , '--no-replica' and '--retention-days' will be ignored when creating a free store.")
+            logger.warning("Options '--enable-purge-protection', '--replica-name', '--replica-location' , '--no-replica' , 'enable-arm-private-network-access' and '--retention-days' will be ignored when creating a free store.")
             namespace.retention_days = None
             namespace.enable_purge_protection = None
             namespace.replica_name = None
@@ -387,6 +406,16 @@ def validate_sku(namespace):
             namespace.enable_arm_private_network_access = None
             return
 
+    if namespace.sku.lower() == 'developer':
+        if (namespace.enable_purge_protection or namespace.retention_days or namespace.replica_name or namespace.replica_location or namespace.no_replica):  # pylint: disable=too-many-boolean-expressions
+            logger.warning("Options '--enable-purge-protection', '--replica-name', '--replica-location' , '--no-replica' and '--retention-days' will be ignored when creating a developer store.")
+            namespace.retention_days = None
+            namespace.enable_purge_protection = None
+            namespace.replica_name = None
+            namespace.replica_location = None
+            namespace.no_replica = None
+            return
+
     if namespace.sku.lower() == 'premium' and not namespace.no_replica:
         if any(arg is None for arg in [namespace.replica_name, namespace.replica_location]):
             raise RequiredArgumentMissingError("Options '--replica-name' and '--replica-location' are required when creating a premium tier store. To avoid creating replica please provide explicit argument '--no-replica'.")
@@ -400,3 +429,32 @@ def validate_sku(namespace):
     else:
         if namespace.replica_location is not None:
             raise RequiredArgumentMissingError("To create a replica, '--replica-name' is required.")
+
+
+def _validate_tag_filter_list(tag_list):
+    if not tag_list or not isinstance(tag_list, list):
+        return
+
+    if len(tag_list) > 5:
+        raise InvalidArgumentValueError("Too many tag filters provided. Maximum allowed is 5.")
+
+    for tag in tag_list:
+        if tag:
+            comps = tag.split('=', 1)
+            if comps[0] == "":
+                raise InvalidArgumentValueError("Tag filter name cannot be empty.")
+
+
+def validate_tag_filters(namespace):
+    """Validates tag filters in the 'tags' attribute."""
+    _validate_tag_filter_list(getattr(namespace, 'tags', None))
+
+
+def validate_import_tag_filters(namespace):
+    """Validates tag filters in the 'src_tags' attribute."""
+    _validate_tag_filter_list(getattr(namespace, 'src_tags', None))
+
+
+def validate_dry_run(namespace):
+    if namespace.dry_run and namespace.yes:
+        raise MutuallyExclusiveArgumentError("The '--dry-run' and '--yes' options cannot be specified together.")
