@@ -29,7 +29,7 @@ from ._models import (KeyValue,
                       convert_configurationsetting_to_keyvalue,
                       convert_keyvalue_to_configurationsetting)
 from ._utils import (get_appconfig_data_client,
-                     prep_label_filter_for_url_encoding,
+                     prep_filter_for_url_encoding,
                      validate_feature_flag_name)
 from ._featuremodels import (map_keyvalue_to_featureflag,
                              map_keyvalue_to_featureflagvalue,
@@ -71,7 +71,11 @@ def set_feature(cmd,
     default_conditions = {FeatureFlagConstants.CLIENT_FILTERS: []}
 
     if requirement_type:
-        default_conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = requirement_type
+        default_conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = (
+            FeatureFlagConstants.REQUIREMENT_TYPE_ALL
+            if requirement_type.lower() == FeatureFlagConstants.REQUIREMENT_TYPE_ALL.lower()
+            else FeatureFlagConstants.REQUIREMENT_TYPE_ANY
+        )
 
     default_value = {
         FeatureFlagConstants.ID: feature,
@@ -125,11 +129,15 @@ def set_feature(cmd,
                     feature_flag_value.description = description
 
                 if requirement_type is not None:
-                    feature_flag_value.conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = requirement_type
+                    feature_flag_value.conditions[FeatureFlagConstants.REQUIREMENT_TYPE] = (
+                        FeatureFlagConstants.REQUIREMENT_TYPE_ALL
+                        if requirement_type.lower() == FeatureFlagConstants.REQUIREMENT_TYPE_ALL.lower()
+                        else FeatureFlagConstants.REQUIREMENT_TYPE_ANY
+                    )
 
                 set_kv = KeyValue(key=key,
                                   label=label,
-                                  value=json.dumps(feature_flag_value, default=lambda o: o.__dict__, ensure_ascii=False),
+                                  value=json.dumps(feature_flag_value, default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None}, ensure_ascii=False),
                                   content_type=FeatureFlagConstants.FEATURE_FLAG_CONTENT_TYPE,
                                   tags=retrieved_kv.tags if tags is None else tags,
                                   etag=retrieved_kv.etag,
@@ -137,7 +145,7 @@ def set_feature(cmd,
 
             # Convert KeyValue object to required FeatureFlag format for
             # display
-            feature_flag = map_keyvalue_to_featureflag(set_kv, show_conditions=True)
+            feature_flag = map_keyvalue_to_featureflag(set_kv, show_all_details=True)
             entry = json.dumps(feature_flag, default=lambda o: o.__dict__, indent=2, sort_keys=True, ensure_ascii=False)
 
         except Exception as exception:
@@ -233,7 +241,7 @@ def delete_feature(cmd,
     # Convert result list of KeyValue to list of FeatureFlag
     deleted_ff = []
     for success_kv in deleted_kvs:
-        success_ff = map_keyvalue_to_featureflag(success_kv, show_conditions=False)
+        success_ff = map_keyvalue_to_featureflag(success_kv, show_all_details=False)
         deleted_ff.append(success_ff)
 
     return deleted_ff
@@ -265,7 +273,7 @@ def show_feature(cmd,
             raise CLIErrors.ResourceNotFoundError("The feature flag does not exist.")
 
         retrieved_kv = convert_configurationsetting_to_keyvalue(config_setting)
-        feature_flag = map_keyvalue_to_featureflag(keyvalue=retrieved_kv, show_conditions=True)
+        feature_flag = map_keyvalue_to_featureflag(keyvalue=retrieved_kv, show_all_details=True)
 
         # If user has specified fields, we still get all the fields and then
         # filter what we need from the response.
@@ -354,7 +362,7 @@ def lock_feature(cmd,
         try:
             new_kv = azconfig_client.set_read_only(retrieved_kv, match_condition=MatchConditions.IfNotModified, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             return map_keyvalue_to_featureflag(convert_configurationsetting_to_keyvalue(new_kv),
-                                               show_conditions=False)
+                                               show_all_details=False)
         except HttpResponseError as exception:
             if exception.status_code == StatusCodes.PRECONDITION_FAILED:
                 logger.debug('Retrying lock operation %s times with exception: concurrent setting operations', i + 1)
@@ -408,7 +416,7 @@ def unlock_feature(cmd,
         try:
             new_kv = azconfig_client.set_read_only(retrieved_kv, read_only=False, match_condition=MatchConditions.IfNotModified, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
             return map_keyvalue_to_featureflag(convert_configurationsetting_to_keyvalue(new_kv),
-                                               show_conditions=False)
+                                               show_all_details=False)
         except HttpResponseError as exception:
             if exception.status_code == StatusCodes.PRECONDITION_FAILED:
                 logger.debug('Retrying unlock operation %s times with exception: concurrent setting operations', i + 1)
@@ -469,11 +477,11 @@ def enable_feature(cmd,
             updated_key_value = __update_existing_key_value(azconfig_client=azconfig_client,
                                                             retrieved_kv=retrieved_kv,
                                                             updated_value=json.dumps(feature_flag_value,
-                                                                                     default=lambda o: o.__dict__,
+                                                                                     default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None},
                                                                                      ensure_ascii=False),
                                                             correlation_request_id=correlation_request_id)
 
-            return map_keyvalue_to_featureflag(keyvalue=updated_key_value, show_conditions=False)
+            return map_keyvalue_to_featureflag(keyvalue=updated_key_value, show_all_details=False)
 
         except HttpResponseError as exception:
             if exception.status_code == StatusCodes.PRECONDITION_FAILED:
@@ -535,11 +543,11 @@ def disable_feature(cmd,
             updated_key_value = __update_existing_key_value(azconfig_client=azconfig_client,
                                                             retrieved_kv=retrieved_kv,
                                                             updated_value=json.dumps(feature_flag_value,
-                                                                                     default=lambda o: o.__dict__,
+                                                                                     default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None},
                                                                                      ensure_ascii=False),
                                                             correlation_request_id=correlation_request_id)
 
-            return map_keyvalue_to_featureflag(keyvalue=updated_key_value, show_conditions=False)
+            return map_keyvalue_to_featureflag(keyvalue=updated_key_value, show_all_details=False)
 
         except HttpResponseError as exception:
             if exception.status_code == StatusCodes.PRECONDITION_FAILED:
@@ -628,7 +636,7 @@ def add_filter(cmd,
             __update_existing_key_value(azconfig_client=azconfig_client,
                                         retrieved_kv=retrieved_kv,
                                         updated_value=json.dumps(feature_flag_value,
-                                                                 default=lambda o: o.__dict__,
+                                                                 default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None},
                                                                  ensure_ascii=False),
                                         correlation_request_id=correlation_request_id)
 
@@ -764,7 +772,7 @@ def update_filter(cmd,
             __update_existing_key_value(azconfig_client=azconfig_client,
                                         retrieved_kv=retrieved_kv,
                                         updated_value=json.dumps(feature_flag_value,
-                                                                 default=lambda o: o.__dict__,
+                                                                 default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None},
                                                                  ensure_ascii=False),
                                         correlation_request_id=correlation_request_id)
 
@@ -887,7 +895,7 @@ def delete_filter(cmd,
             __update_existing_key_value(azconfig_client=azconfig_client,
                                         retrieved_kv=retrieved_kv,
                                         updated_value=json.dumps(feature_flag_value,
-                                                                 default=lambda o: o.__dict__,
+                                                                 default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None},
                                                                  ensure_ascii=False),
                                         correlation_request_id=correlation_request_id)
 
@@ -948,7 +956,6 @@ def show_filter(cmd,
         # detailed message
         feature_flag_value = map_keyvalue_to_featureflagvalue(retrieved_kv)
         feature_filters = feature_flag_value.conditions[FeatureFlagConstants.CLIENT_FILTERS]
-
         display_filters = []
 
         # If user has specified index, we use it as secondary check to display
@@ -1032,6 +1039,7 @@ def __list_features(
     key=None,
     name=None,
     label=None,
+    tags=None,
     fields=None,
     connection_string=None,
     top=None,
@@ -1062,6 +1070,7 @@ def __list_features(
             azconfig_client,
             key_filter=key_filter,
             label=label if label else SearchFilterOptions.ANY_LABEL,
+            tags=tags,
             correlation_request_id=correlation_request_id,
         )
         retrieved_featureflags = []
@@ -1070,7 +1079,7 @@ def __list_features(
         for kv in retrieved_keyvalues:
             try:
                 retrieved_featureflags.append(
-                    map_keyvalue_to_featureflag(keyvalue=kv, show_conditions=True)
+                    map_keyvalue_to_featureflag(keyvalue=kv, show_all_details=True)
                 )
             except ValueError as exception:
                 logger.warning("%s\n", exception)
@@ -1151,9 +1160,7 @@ def __clear_filter(azconfig_client, feature, label=None, yes=False):
 
             # These fields will never be missing because we validate that
             # in map_keyvalue_to_featureflagvalue
-            feature_filters = feature_flag_value.conditions[
-                FeatureFlagConstants.CLIENT_FILTERS
-            ]
+            feature_filters = feature_flag_value.conditions[FeatureFlagConstants.CLIENT_FILTERS]
 
             # create a deep copy of the filters to display to the user
             # after deletion
@@ -1173,7 +1180,7 @@ def __clear_filter(azconfig_client, feature, label=None, yes=False):
                     retrieved_kv=retrieved_kv,
                     updated_value=json.dumps(
                         feature_flag_value,
-                        default=lambda o: o.__dict__,
+                        default=lambda o: {k: v for k, v in o.__dict__.items() if v is not None},
                         ensure_ascii=False,
                     ),
                 )
@@ -1233,6 +1240,7 @@ def __update_existing_key_value(azconfig_client,
 def __list_all_keyvalues(azconfig_client,
                          key_filter,
                          label=None,
+                         tags=None,
                          correlation_request_id=None):
     '''
         To get all keys by name or pattern
@@ -1241,6 +1249,7 @@ def __list_all_keyvalues(azconfig_client,
             azconfig_client - AppConfig client making calls to the service
             key_filter - Filter for the key of the feature flag
             label - Feature label or pattern
+            tags - Tags to filter the feature flags
 
         Return:
             List of KeyValue objects
@@ -1254,10 +1263,11 @@ def __list_all_keyvalues(azconfig_client,
     if unescaped_comma_regex.search(key_filter):
         raise CLIError("Comma separated feature names are not supported. Please provide escaped string if your feature name contains comma. \nSee \"az appconfig feature list -h\" for correct usage.")
 
-    label = prep_label_filter_for_url_encoding(label)
+    label = prep_filter_for_url_encoding(label)
+    prepped_tags = [prep_filter_for_url_encoding(tag) for tag in tags] if tags else []
 
     try:
-        configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
+        configsetting_iterable = azconfig_client.list_configuration_settings(key_filter=key_filter, label_filter=label, tags_filter=prepped_tags, headers={HttpHeaders.CORRELATION_REQUEST_ID: correlation_request_id})
     except HttpResponseError as exception:
         raise CLIErrors.AzureResponseError('Failed to read feature flag(s) that match the specified feature and label. ' + str(exception))
 
