@@ -11,6 +11,27 @@ import sys
 import uuid
 
 from itertools import chain
+
+from ._kv_export_helpers import (
+    __export_kvset_to_file,
+    __map_to_appservice_config_reference,
+    __write_kv_and_features_to_file,
+    __write_kv_to_app_service,
+)
+from ._kv_helpers import (
+    __convert_featureflag_list_to_keyvalue_list,
+    __discard_features_from_retrieved_kv,
+    __read_kv_from_config_store,
+    __write_kv_and_features_to_config_store,
+    __print_restore_preview
+)
+from ._kv_import_helpers import (
+    __import_kvset_from_file,
+    __delete_configuration_setting_from_config_store,
+    __read_features_from_file,
+    __read_kv_from_app_service,
+    __read_kv_from_file,
+)
 from knack.log import get_logger
 from knack.util import CLIError
 from ._constants import HttpHeaders
@@ -31,15 +52,8 @@ from ._constants import (FeatureFlagConstants, KeyVaultConstants,
                          JsonDiff, ImportMode)
 from ._featuremodels import map_keyvalue_to_featureflag
 from ._models import (convert_configurationsetting_to_keyvalue, convert_keyvalue_to_configurationsetting)
-from ._utils import get_appconfig_data_client, prep_label_filter_for_url_encoding, resolve_store_metadata, get_store_endpoint_from_connection_string, is_json_content_type
+from ._utils import get_appconfig_data_client, prep_filter_for_url_encoding, resolve_store_metadata, get_store_endpoint_from_connection_string, is_json_content_type
 
-from ._kv_helpers import (__read_kv_from_file, __read_features_from_file,
-                          __write_kv_and_features_to_file, __read_kv_from_config_store,
-                          __write_kv_and_features_to_config_store,
-                          __discard_features_from_retrieved_kv, __read_kv_from_app_service,
-                          __write_kv_to_app_service, __print_restore_preview,
-                          __convert_featureflag_list_to_keyvalue_list, __export_kvset_to_file,
-                          __import_kvset_from_file, __delete_configuration_setting_from_config_store, __map_to_appservice_config_reference)
 from ._diff_utils import print_preview, KVComparer
 from .feature import __list_features
 
@@ -51,6 +65,7 @@ def import_config(cmd,
                   name=None,
                   connection_string=None,
                   label=None,
+                  tags=None,  # tags to add
                   prefix="",  # prefix to add
                   yes=False,
                   skip_features=False,
@@ -58,6 +73,7 @@ def import_config(cmd,
                   auth_mode="key",
                   endpoint=None,
                   import_mode=ImportMode.IGNORE_MATCH,
+                  dry_run=False,
                   # from-file parameters
                   path=None,
                   format_=None,
@@ -74,6 +90,7 @@ def import_config(cmd,
                   preserve_labels=False,
                   src_auth_mode="key",
                   src_endpoint=None,
+                  src_tags=None,  # tags to filter
                   # from-appservice parameters
                   appservice_account=None):
 
@@ -92,7 +109,7 @@ def import_config(cmd,
     # fetch key values from source
     if source == 'file':
         if profile == ImportExportProfiles.KVSET:
-            __import_kvset_from_file(client=azconfig_client, path=path, strict=strict, yes=yes, import_mode=import_mode, correlation_request_id=correlation_request_id)
+            __import_kvset_from_file(client=azconfig_client, path=path, strict=strict, yes=yes, dry_run=dry_run, import_mode=import_mode, correlation_request_id=correlation_request_id)
             return
         if format_ and content_type:
             # JSON content type is only supported with JSON format.
@@ -133,6 +150,7 @@ def import_config(cmd,
                                               key=src_key,
                                               snapshot=src_snapshot,
                                               label=src_label if src_label else SearchFilterOptions.EMPTY_LABEL,
+                                              tags=src_tags,
                                               prefix_to_add=prefix,
                                               correlation_request_id=correlation_request_id)
 
@@ -140,10 +158,11 @@ def import_config(cmd,
             if src_snapshot:
                 all_features = [kv for kv in src_kvs if kv.key.startswith(FeatureFlagConstants.FEATURE_FLAG_PREFIX)]
             else:
-                # Get all Feature flags with matching label
+                # Get all Feature flags with matching label and tags
                 all_features = __read_kv_from_config_store(src_azconfig_client,
                                                            key=FeatureFlagConstants.FEATURE_FLAG_PREFIX + '*',
                                                            label=src_label if src_label else SearchFilterOptions.EMPTY_LABEL,
+                                                           tags=src_tags,
                                                            correlation_request_id=correlation_request_id)
 
             for feature in all_features:
@@ -201,7 +220,7 @@ def import_config(cmd,
         ff_diff = ff_comparer.compare(dest_kvs=dest_features, strict=strict, ignore_matching_kvs=import_mode == ImportMode.IGNORE_MATCH)
         need_feature_change = print_preview(ff_diff, source, yes=yes, strict=strict, title="Feature Flags")
 
-    if not need_kv_change and not need_feature_change:
+    if (not need_kv_change and not need_feature_change) or dry_run:
         return
 
     if not yes:
@@ -235,6 +254,7 @@ def import_config(cmd,
     __write_kv_and_features_to_config_store(azconfig_client,
                                             key_values=kvs_to_write,
                                             label=label,
+                                            tags=tags,
                                             preserve_labels=preserve_labels,
                                             content_type=content_type,
                                             correlation_request_id=correlation_request_id)
@@ -246,6 +266,7 @@ def export_config(cmd,
                   connection_string=None,
                   label=None,
                   key=None,
+                  tags=None,  # tags to filter
                   prefix="",  # prefix to remove
                   yes=False,
                   skip_features=False,
@@ -253,6 +274,7 @@ def export_config(cmd,
                   auth_mode="key",
                   endpoint=None,
                   snapshot=None,
+                  dry_run=False,
                   # to-file parameters
                   path=None,
                   format_=None,
@@ -267,6 +289,7 @@ def export_config(cmd,
                   preserve_labels=False,
                   dest_auth_mode="key",
                   dest_endpoint=None,
+                  dest_tags=None,  # tags to add
                   # to-app-service parameters
                   appservice_account=None,
                   export_as_reference=False):
@@ -299,6 +322,7 @@ def export_config(cmd,
     src_kvs = __read_kv_from_config_store(azconfig_client,
                                           key=key,
                                           label=label if label else SearchFilterOptions.EMPTY_LABEL,
+                                          tags=tags,
                                           prefix_to_remove=prefix if not export_as_reference else "",
                                           snapshot=snapshot,
                                           cli_ctx=cmd.cli_ctx if resolve_keyvault else None,
@@ -323,6 +347,7 @@ def export_config(cmd,
                     cmd,
                     feature="*",
                     label=label if label else SearchFilterOptions.EMPTY_LABEL,
+                    tags=tags,
                     name=name,
                     connection_string=connection_string,
                     all_=True,
@@ -337,7 +362,7 @@ def export_config(cmd,
         __discard_features_from_retrieved_kv(src_kvs)
 
     if profile == ImportExportProfiles.KVSET:
-        __export_kvset_to_file(file_path=path, keyvalues=src_kvs, yes=yes)
+        __export_kvset_to_file(file_path=path, keyvalues=src_kvs, yes=yes, dry_run=dry_run)
         return
 
     if destination == 'appservice' and export_as_reference:
@@ -396,8 +421,9 @@ def export_config(cmd,
         ff_diff = ff_comparer.compare(dest_kvs=__convert_featureflag_list_to_keyvalue_list(dest_features))
         need_feature_change = print_preview(ff_diff, destination, yes=yes, title="Feature Flags")
 
-    if not need_feature_change and not need_kv_change:
+    if (not need_feature_change and not need_kv_change) or dry_run:
         return
+
     # if customer needs preview & confirmation
     if not yes:
         user_confirmation("Do you want to continue? \n")
@@ -409,7 +435,7 @@ def export_config(cmd,
                                         naming_convention=naming_convention)
     elif destination == 'appconfig':
         __write_kv_and_features_to_config_store(dest_azconfig_client, key_values=src_kvs, features=src_features,
-                                                label=dest_label, preserve_labels=preserve_labels,
+                                                label=dest_label, tags=dest_tags, preserve_labels=preserve_labels,
                                                 correlation_request_id=correlation_request_id)
     elif destination == 'appservice':
         __write_kv_to_app_service(cmd, key_values=src_kvs, appservice_account=appservice_account)
@@ -600,6 +626,7 @@ def delete_key(cmd,
                key,
                name=None,
                label=None,
+               tags=None,
                yes=False,
                connection_string=None,
                auth_mode="key",
@@ -617,8 +644,9 @@ def delete_key(cmd,
     entries = __read_kv_from_config_store(azconfig_client,
                                           key=key,
                                           label=label if label else SearchFilterOptions.EMPTY_LABEL,
+                                          tags=tags,
                                           correlation_request_id=correlation_request_id)
-    confirmation_message = "Found '{}' key-values matching the specified key and label. Are you sure you want to delete these key-values?".format(len(entries))
+    confirmation_message = "Found '{}' key-values matching the specified key, label and tags. Are you sure you want to delete these key-values?".format(len(entries))
     user_confirmation(confirmation_message, yes)
 
     deleted_entries = []
@@ -760,6 +788,7 @@ def list_key(cmd,
              fields=None,
              name=None,
              label=None,
+             tags=None,
              datetime=None,
              snapshot=None,
              connection_string=None,
@@ -779,6 +808,7 @@ def list_key(cmd,
     keyvalues = __read_kv_from_config_store(azconfig_client,
                                             key=key if key else SearchFilterOptions.ANY_KEY,
                                             label=label if label else SearchFilterOptions.ANY_LABEL,
+                                            tags=tags,
                                             datetime=datetime,
                                             snapshot=snapshot,
                                             fields=fields,
@@ -793,9 +823,11 @@ def restore_key(cmd,
                 key=None,
                 name=None,
                 label=None,
+                tags=None,
                 connection_string=None,
                 yes=False,
                 auth_mode="key",
+                dry_run=False,
                 endpoint=None):
     azconfig_client = get_appconfig_data_client(cmd, name, connection_string, auth_mode, endpoint)
 
@@ -806,11 +838,13 @@ def restore_key(cmd,
     restore_keyvalues = __read_kv_from_config_store(azconfig_client,
                                                     key=key if key else SearchFilterOptions.ANY_KEY,
                                                     label=label if label else SearchFilterOptions.ANY_LABEL,
+                                                    tags=tags,
                                                     datetime=datetime,
                                                     correlation_request_id=correlation_request_id)
     current_keyvalues = __read_kv_from_config_store(azconfig_client,
                                                     key=key if key else SearchFilterOptions.ANY_KEY,
                                                     label=label if label else SearchFilterOptions.ANY_LABEL,
+                                                    tags=tags,
                                                     correlation_request_id=correlation_request_id)
 
     try:
@@ -819,11 +853,10 @@ def restore_key(cmd,
 
         need_change = __print_restore_preview(restore_diff, yes=yes)
 
-        if not yes:
-            if need_change is False:
-                logger.debug('Canceling the restore operation based on user selection.')
-                return
+        if dry_run or not need_change:
+            return
 
+        if not yes:
             user_confirmation("Do you want to continue? \n")
 
         kvs_to_restore = restore_diff.get(JsonDiff.ADD, [])
@@ -878,6 +911,7 @@ def list_revision(cmd,
                   fields=None,
                   name=None,
                   label=None,
+                  tags=None,
                   datetime=None,
                   connection_string=None,
                   top=None,
@@ -888,7 +922,8 @@ def list_revision(cmd,
 
     key = key if key else SearchFilterOptions.ANY_KEY
     label = label if label else SearchFilterOptions.ANY_LABEL
-    label = prep_label_filter_for_url_encoding(label)
+    label = prep_filter_for_url_encoding(label)
+    prepped_tags = [prep_filter_for_url_encoding(tag) for tag in tags] if tags else []
 
     try:
         query_fields = None
@@ -899,6 +934,7 @@ def list_revision(cmd,
 
         revisions_iterable = azconfig_client.list_revisions(key_filter=key,
                                                             label_filter=label,
+                                                            tags_filter=prepped_tags,
                                                             accept_datetime=datetime,
                                                             fields=query_fields)
         retrieved_revisions = []
