@@ -8,16 +8,15 @@ from datetime import datetime, timedelta
 from importlib import import_module
 import re
 from dateutil.tz import tzutc   # pylint: disable=import-error
-from msrestazure.azure_exceptions import CloudError
-from msrestazure.tools import resource_id, is_valid_resource_id, parse_resource_id  # pylint: disable=import-error
 from knack.log import get_logger
 from knack.util import todict
 from urllib.request import urlretrieve
-from azure.core.exceptions import ResourceNotFoundError
+from azure.core.exceptions import ResourceNotFoundError, HttpResponseError
 from azure.cli.core._profile import Profile
 from azure.cli.core.commands.client_factory import get_subscription_id
 from azure.cli.core.util import CLIError, sdk_no_wait
 from azure.cli.core.local_context import ALL
+from azure.mgmt.core.tools import resource_id, is_valid_resource_id, parse_resource_id
 from azure.mgmt.rdbms import postgresql, mysql, mariadb
 from azure.mgmt.rdbms.mysql.operations._servers_operations import ServersOperations as MySqlServersOperations
 from azure.mgmt.rdbms.postgresql.operations._location_based_performance_tier_operations import LocationBasedPerformanceTierOperations as PostgreSQLLocationOperations
@@ -36,6 +35,7 @@ SKU_TIER_MAP = {'Basic': 'b', 'GeneralPurpose': 'gp', 'MemoryOptimized': 'mo'}
 DEFAULT_DB_NAME = 'defaultdb'
 MYSQL_RETIRE_WARNING_MSG = 'Azure Database for MySQL - Single Server is scheduled for retirement (https://go.microsoft.com/fwlink/?linkid=2216041) by September 16, 2024. Migrate (https://go.microsoft.com/fwlink/?linkid=2202255) to Azure Database for MySQL- Flexible Server now.'
 MARIADB_RETIRE_WARNING_MSG = 'Azure Database for MariaDB is scheduled for retirement (https://go.microsoft.com/fwlink/?linkid=2248931) by September 19, 2025. Migrate (https://go.microsoft.com/fwlink/?linkid=2263092) to Azure Database for MySQL- Flexible Server now.'
+POSTGRESQL_RETIRE_WARNING_MSG = 'Azure Database for PostgreSQL – Single Server is scheduled for retirement by March 28 2025, (https://go.microsoft.com/fwlink/?linkid=2300058). Migrate to Azure Database for PostgreSQL flexible server now, (https://go.microsoft.com/fwlink/?linkid=2197657).'
 
 
 # pylint: disable=too-many-locals, too-many-statements, raise-missing-from
@@ -48,6 +48,8 @@ def _server_create(cmd, client, resource_group_name=None, server_name=None, sku_
         provider = 'Microsoft.DBforMySQL'
     elif isinstance(client, MariaDBServersOperations):
         provider = 'Microsoft.DBforMariaDB'
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     server_result = firewall_id = None
     administrator_login_password = generate_password(administrator_login_password)
@@ -198,6 +200,8 @@ def _server_restore(cmd, client, resource_group_name, server_name, source_server
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
         provider = 'Microsoft.DBforMariaDB'
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     parameters = None
     if not is_valid_resource_id(source_server):
@@ -257,6 +261,8 @@ def _server_georestore(cmd, client, resource_group_name, server_name, sku_name,
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
         provider = 'Microsoft.DBforMariaDB'
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     parameters = None
 
@@ -320,6 +326,8 @@ def _replica_create(cmd, client, resource_group_name, server_name, source_server
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
         provider = 'Microsoft.DBforMariaDB'
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     # set source server id
     if not is_valid_resource_id(source_server):
         if len(source_server.split('/')) == 1:
@@ -334,7 +342,7 @@ def _replica_create(cmd, client, resource_group_name, server_name, source_server
     source_server_id_parts = parse_resource_id(source_server)
     try:
         source_server_object = client.get(source_server_id_parts['resource_group'], source_server_id_parts['name'])
-    except CloudError as e:
+    except HttpResponseError as e:
         raise CLIError('Unable to get source server: {}.'.format(str(e)))
 
     if location is None:
@@ -368,6 +376,8 @@ def _replica_stop(client, resource_group_name, server_name):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     try:
         server_object = client.get(resource_group_name, server_name)
@@ -403,6 +413,8 @@ def _server_update_custom_func(client,
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     server_module_path = instance.__module__
     module = import_module(server_module_path.replace('server', 'server_update_parameters'))
@@ -474,6 +486,8 @@ def _server_stop(cmd, client, resource_group_name, server_name):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     logger.warning("Server will be automatically started after 7 days "
                    "if you do not perform a manual start operation")
@@ -481,6 +495,7 @@ def _server_stop(cmd, client, resource_group_name, server_name):
 
 
 def _server_postgresql_get(cmd, resource_group_name, server_name):
+    logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     client = get_postgresql_management_client(cmd.cli_ctx)
     return client.servers.get(resource_group_name, server_name)
 
@@ -490,6 +505,8 @@ def _server_update_get(client, resource_group_name, server_name):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     return client.get(resource_group_name, server_name)
 
@@ -499,6 +516,8 @@ def _server_update_set(client, resource_group_name, server_name, parameters):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     return client.begin_update(resource_group_name, server_name, parameters)
 
@@ -508,6 +527,8 @@ def _server_delete(cmd, client, resource_group_name, server_name):
     if isinstance(client, MySqlServersOperations):
         database_engine = 'mysql'
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     result = client.begin_delete(resource_group_name, server_name)
 
@@ -527,6 +548,8 @@ def _firewall_rule_create(client, resource_group_name, server_name, firewall_rul
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     parameters = {'name': firewall_rule_name, 'start_ip_address': start_ip_address, 'end_ip_address': end_ip_address}
 
@@ -538,6 +561,8 @@ def _firewall_rule_custom_getter(client, resource_group_name, server_name, firew
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     return client.get(resource_group_name, server_name, firewall_rule_name)
 
@@ -547,6 +572,8 @@ def _firewall_rule_custom_setter(client, resource_group_name, server_name, firew
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     return client.begin_create_or_update(
         resource_group_name,
         server_name,
@@ -559,6 +586,8 @@ def _firewall_rule_update_custom_func(client, instance, start_ip_address=None, e
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     if start_ip_address is not None:
         instance.start_ip_address = start_ip_address
     if end_ip_address is not None:
@@ -571,6 +600,8 @@ def _vnet_rule_create(client, resource_group_name, server_name, virtual_network_
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     parameters = {
         'name': virtual_network_rule_name,
@@ -586,6 +617,8 @@ def _custom_vnet_update_getter(client, resource_group_name, server_name, virtual
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     return client.get(resource_group_name, server_name, virtual_network_rule_name)
 
 
@@ -594,6 +627,8 @@ def _custom_vnet_update_setter(client, resource_group_name, server_name, virtual
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     return client.begin_create_or_update(
         resource_group_name,
         server_name,
@@ -606,6 +641,8 @@ def _vnet_rule_update_custom_func(client, instance, virtual_network_subnet_id, i
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     instance.virtual_network_subnet_id = virtual_network_subnet_id
     if ignore_missing_vnet_service_endpoint is not None:
         instance.ignore_missing_vnet_service_endpoint = ignore_missing_vnet_service_endpoint
@@ -617,6 +654,8 @@ def _configuration_update(client, resource_group_name, server_name, configuratio
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     parameters = {
         'name': configuration_name,
         'value': value,
@@ -631,6 +670,8 @@ def _db_create(client, resource_group_name, server_name, database_name, charset=
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
     parameters = {
         'name': database_name,
         'charset': charset,
@@ -650,6 +691,8 @@ def _download_log_files(
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     # list all files
     files = client.list_by_server(resource_group_name, server_name)
@@ -665,6 +708,8 @@ def _list_log_files_with_filter(client, resource_group_name, server_name, filena
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     # list all files
     all_files = client.list_by_server(resource_group_name, server_name)
@@ -694,6 +739,8 @@ def _server_list_custom_func(client, resource_group_name=None):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     if resource_group_name:
         return client.list_by_resource_group(resource_group_name)
@@ -727,6 +774,8 @@ def approve_private_endpoint_connection(cmd, client, resource_group_name, server
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     return _update_private_endpoint_connection_status(
         cmd, client, resource_group_name, server_name, private_endpoint_connection_name, is_approved=True,
@@ -740,6 +789,8 @@ def reject_private_endpoint_connection(cmd, client, resource_group_name, server_
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
     elif isinstance(client, MariaDBServersOperations):
         logger.warning(MARIADB_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     return _update_private_endpoint_connection_status(
         cmd, client, resource_group_name, server_name, private_endpoint_connection_name, is_approved=False,
@@ -750,6 +801,8 @@ def server_key_create(client, resource_group_name, server_name, kid):
     """Create Server Key."""
     if isinstance(client, MySqlServersOperations):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     key_name = _get_server_key_name_from_uri(kid)
 
@@ -766,6 +819,8 @@ def server_key_get(client, resource_group_name, server_name, kid):
     """Get Server Key."""
     if isinstance(client, MySqlServersOperations):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     key_name = _get_server_key_name_from_uri(kid)
 
@@ -780,6 +835,8 @@ def server_key_delete(cmd, client, resource_group_name, server_name, kid):
     """Drop Server Key."""
     if isinstance(client, MySqlServersOperations):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     key_name = _get_server_key_name_from_uri(kid)
 
@@ -816,6 +873,8 @@ def server_ad_admin_set(client, resource_group_name, server_name, login=None, si
 
     if isinstance(client, MySqlServersOperations):
         logger.warning(MYSQL_RETIRE_WARNING_MSG)
+    else:
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
 
     parameters = {
         'administratorType': 'ActiveDirectory',
@@ -950,6 +1009,7 @@ def get_connection_string(cmd, client, server_name='{server}', database_name='{d
             result[k] = v.format(**connection_kwargs)
 
     if provider == 'PostgreSQL':
+        logger.warning(POSTGRESQL_RETIRE_WARNING_MSG)
         server_endpoint = cmd.cli_ctx.cloud.suffixes.postgresql_server_endpoint
         host = '{}{}'.format(server_name, server_endpoint)
         result = {
