@@ -8,23 +8,18 @@
 import os
 import time
 
+from urllib.parse import urlparse
+
 from OpenSSL import crypto
 from cryptography.hazmat.primitives.serialization import pkcs12
 from cryptography.hazmat.primitives import hashes
 
-try:
-    from urllib.parse import urlparse
-except ImportError:
-    from urlparse import urlparse  # pylint: disable=import-error
-
-from msrestazure.azure_exceptions import CloudError
-
 from azure.cli.core.util import CLIError, get_file_json, b64_to_hex, sdk_no_wait
 from azure.cli.core.commands import LongRunningOperation
 from azure.cli.core.profiles import ResourceType, get_sdk
 from azure.cli.command_modules.servicefabric._arm_deployment_utils import validate_and_deploy_arm_template
 from azure.cli.command_modules.servicefabric._sf_utils import _get_resource_group_by_name, _create_resource_group_name
-from azure.core.exceptions import ResourceNotFoundError
+from azure.core.exceptions import ResourceNotFoundError, HttpResponseError
 
 from azure.mgmt.servicefabric.models import (ClusterUpdateParameters,
                                              ClientCertificateThumbprint,
@@ -338,13 +333,20 @@ def add_client_cert(cmd,
             ClientCertificateThumbprint(is_admin, thumbprint))
 
     def _add_common_name(cluster, is_admin, certificate_common_name, certificate_issuer_thumbprint):
+        remove = False
         for t in cluster.client_certificate_common_names:
             if t.certificate_common_name.lower() == certificate_common_name.lower() and t.certificate_issuer_thumbprint.lower() == certificate_issuer_thumbprint.lower():
                 remove = t
+
         if remove:
             cluster.client_certificate_common_names.remove(remove)
-        cluster.client_certificate_common_names.add(ClientCertificateCommonName(
-            is_admin, certificate_common_name, certificate_issuer_thumbprint))
+
+        client_certificate_common_name = ClientCertificateCommonName(
+            is_admin=is_admin,
+            certificate_common_name=certificate_common_name,
+            certificate_issuer_thumbprint=certificate_issuer_thumbprint,
+        )
+        cluster.client_certificate_common_names.append(client_certificate_common_name)
         return cluster.client_certificate_common_names
 
     if thumbprint:
@@ -1359,8 +1361,8 @@ def _safe_get_vault(cli_ctx, resource_group_name, vault_name):
         return vault
     except ResourceNotFoundError:
         return None
-    except CloudError as ex:
-        if ex.error.error == 'ResourceNotFound':
+    except HttpResponseError as ex:
+        if ex.status_code == '404':
             return None
         raise
 
@@ -1652,7 +1654,7 @@ def _get_current_user_object_id(graph_client):
         current_user = graph_client.signed_in_user.get()
         if current_user and current_user.object_id:  # pylint:disable=no-member
             return current_user.object_id  # pylint:disable=no-member
-    except CloudError:
+    except HttpResponseError:
         pass
 
 
