@@ -12,14 +12,10 @@ from azure.cli.command_modules.vm._client_factory import (cf_vm,
                                                           cf_proximity_placement_groups,
                                                           cf_dedicated_hosts, cf_dedicated_host_groups,
                                                           cf_log_analytics_data_plane,
-                                                          cf_shared_gallery_image,
-                                                          cf_shared_gallery_image_version,
                                                           cf_capacity_reservation_groups, cf_capacity_reservations,
                                                           cf_vmss_run_commands,
                                                           cf_restore_point,
-                                                          cf_restore_point_collection, cf_community_gallery,
-                                                          cf_community_gallery_image,
-                                                          cf_community_gallery_image_version)
+                                                          cf_restore_point_collection, cf_community_gallery)
 from azure.cli.command_modules.vm._format import (
     transform_ip_addresses, transform_vm, transform_vm_create_output, transform_vm_usage_list, transform_vm_list,
     transform_disk_create_table_output, transform_sku_for_table_output, transform_disk_show_table_output,
@@ -214,14 +210,6 @@ def load_command_table(self, _):
         operations_tmpl='azure.mgmt.compute.operations#CommunityGalleriesOperations.{}',
         client_factory=cf_community_gallery)
 
-    community_gallery_image_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#CommunityGalleryImagesOperations.{}',
-        client_factory=cf_community_gallery_image)
-
-    community_gallery_image_version_sdk = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#CommunityGalleryImageVersionsOperations.{}',
-        client_factory=cf_community_gallery_image_version)
-
     with self.command_group("ppg"):
         from .operations.ppg import PPGShow
         self.command_table["ppg show"] = PPGShow(loader=self)
@@ -314,9 +302,7 @@ def load_command_table(self, _):
         g.custom_command('application set', 'set_vm_applications', validator=process_set_applications_namespace, min_api='2021-07-01')
         g.custom_command('application list', 'list_vm_applications', min_api='2021-07-01')
 
-        g.custom_command('capture', 'capture_vm')
         g.custom_command('create', 'create_vm', transform=transform_vm_create_output, supports_no_wait=True, table_transformer=deployment_validate_table_format, validator=process_vm_create_namespace, exception_handler=handle_template_based_exception)
-        g.command('delete', 'begin_delete', confirmation=True, supports_no_wait=True)
         g.custom_command('get-instance-view', 'get_instance_view', table_transformer='{Name:name, ResourceGroup:resourceGroup, Location:location, ProvisioningState:provisioningState, PowerState:instanceView.statuses[1].displayStatus}')
         g.custom_command('list', 'list_vm', table_transformer=transform_vm_list)
         g.custom_command('list-ip-addresses', 'list_vm_ip_addresses', table_transformer=transform_ip_addresses)
@@ -332,6 +318,9 @@ def load_command_table(self, _):
         g.custom_command('auto-shutdown', 'auto_shutdown_vm')
         g.custom_command('list-sizes', 'list_vm_sizes', deprecate_info=g.deprecate(redirect='az vm list-skus'))
 
+        from .operations.vm import VMCapture
+        self.command_table['vm capture'] = VMCapture(loader=self)
+
     with self.command_group('vm', compute_vm_sdk, client_factory=cf_vm) as g:
         g.custom_command('install-patches', 'install_vm_patches', supports_no_wait=True, min_api='2020-12-01')
 
@@ -363,7 +352,6 @@ def load_command_table(self, _):
         g.custom_show_command('show', 'show_extensions', table_transformer=transform_extension_show_table_output)
         g.custom_command('set', 'set_extension', supports_no_wait=True)
         g.custom_command('list', 'list_extensions', table_transformer='[].' + transform_extension_show_table_output)
-        g.wait_command('wait')
 
     with self.command_group('vm extension image', compute_vm_extension_image_sdk) as g:
         g.custom_command('list', 'list_vm_extension_images')
@@ -496,17 +484,15 @@ def load_command_table(self, _):
     with self.command_group('sig', community_gallery_sdk, client_factory=cf_community_gallery, operation_group='shared_galleries', min_api='2022-01-03') as g:
         g.custom_command('list-community', 'sig_community_gallery_list')
 
-    with self.command_group('sig image-definition', community_gallery_image_sdk, client_factory=cf_community_gallery_image, operation_group='shared_galleries', min_api='2022-01-03') as g:
-        g.custom_command('list-community', 'sig_community_image_definition_list')
-
-    with self.command_group('sig image-version', community_gallery_image_version_sdk, client_factory=cf_community_gallery_image_version, operation_group='shared_galleries', min_api='2022-01-03') as g:
-        g.custom_command('list-community', 'sig_community_image_version_list')
-
     with self.command_group('sig image-definition', compute_gallery_images_sdk, operation_group='gallery_images', min_api='2018-06-01') as g:
         g.custom_command('create', 'create_gallery_image')
         from .operations.sig_image_definition import SigImageDefinitionUpdate
         self.command_table['sig image-definition update'] = SigImageDefinitionUpdate(loader=self)
 
+    with self.command_group('sig image-definition'):
+        from .operations.sig_image_definition import SigImageDefinitionListShared
+        self.command_table['sig image-definition list-shared'] = SigImageDefinitionListShared(loader=self)
+
     with self.command_group('sig image-version', compute_gallery_image_versions_sdk, operation_group='gallery_image_versions', min_api='2018-06-01') as g:
         g.custom_command('create', 'create_image_version', supports_no_wait=True, validator=process_image_version_create_namespace)
         g.custom_command('undelete', 'undelete_image_version', supports_no_wait=True, validator=process_image_version_undelete_namespace, is_preview=True)
@@ -514,6 +500,9 @@ def load_command_table(self, _):
         from .aaz.latest.sig.image_version import Show as SigImageVersionShow
         self.command_table['sig image-version show'] = SigImageVersionShow(loader=self,
                                                                            table_transformer='{Name:name, ResourceGroup:resourceGroup, ProvisioningState:provisioningState, TargetRegions: publishingProfile.targetRegions && join(`, `, publishingProfile.targetRegions[*].name), EdgeZones: publishingProfile.targetExtendedLocations && join(`, `, publishingProfile.targetExtendedLocations[*].name), ReplicationState:replicationStatus.aggregatedState}')
+    with self.command_group('sig image-version'):
+        from .operations.sig_image_version import SigImageVersionListShared
+        self.command_table['sig image-version list-shared'] = SigImageVersionListShared(loader=self)
 
     vm_gallery_sharing_profile = CliCommandType(
         operations_tmpl=(
@@ -529,24 +518,6 @@ def load_command_table(self, _):
         self.command_table['sig share enable-community'] = SigShareEnableCommunity(loader=self)
         self.command_table['sig share wait'] = SigShareWait(loader=self)
 
-    vm_shared_gallery_image = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations._shared_gallery_images_operations#SharedGalleryImagesOperations.'
-        '{}',
-        client_factory=cf_shared_gallery_image,
-        operation_group='shared_galleries')
-    with self.command_group('sig image-definition', vm_shared_gallery_image, min_api='2020-09-30', operation_group='shared_galleries',
-                            client_factory=cf_shared_gallery_image) as g:
-        g.custom_command('list-shared', 'sig_shared_image_definition_list')
-
-    vm_shared_gallery_image_version = CliCommandType(
-        operations_tmpl='azure.mgmt.compute.operations#SharedGalleryImageVersionsOperations.{}',
-        client_factory=cf_shared_gallery_image_version,
-        operation_group='shared_galleries')
-    with self.command_group('sig image-version', vm_shared_gallery_image_version, min_api='2020-09-30',
-                            operation_group='shared_galleries',
-                            client_factory=cf_shared_gallery_image_version) as g:
-        g.custom_command('list-shared', 'sig_shared_image_version_list')
-
     with self.command_group('sig gallery-application', compute_gallery_application_profile, operation_group='gallery_applications') as g:
         from .operations.sig_gallery_application import SigGalleryApplicationCreate
         self.command_table['sig gallery-application create'] = SigGalleryApplicationCreate(loader=self)
@@ -564,7 +535,7 @@ def load_command_table(self, _):
     with self.command_group('vm monitor log', client_factory=cf_log_analytics_data_plane) as g:
         g.custom_command('show', 'execute_query_for_vm', transform=transform_log_analytics_query_output)  # pylint: disable=show-command
 
-    with self.command_group('vm monitor metrics', custom_command_type=monitor_custom, command_type=metric_definitions_sdk, resource_type=ResourceType.MGMT_MONITOR, operation_group='metric_definitions', min_api='2018-01-01', is_preview=True) as g:
+    with self.command_group('vm monitor metrics', custom_command_type=monitor_custom, command_type=metric_definitions_sdk, resource_type=ResourceType.MGMT_MONITOR, operation_group='metric_definitions', is_preview=True) as g:
         from azure.cli.command_modules.monitor.transformers import metrics_table, metrics_definitions_table
         from azure.cli.core.profiles._shared import APIVersionException
         try:
